/*
 * uartlib.h
 *
 *  Created on: 08.07.2011
 *      Author: jmm
 */

#ifndef UARTLIB_H_
#define UARTLIB_H_

/***********************************************/
// SETTINGS

// DEFINE FRAME_FORMAT
#define UART_FRAME_8N1 1

// UART I/O BUFFER SIZE
#define UART_BUFFER_SIZE 128

// SELECT FUNCTIONALITY
#define UART_FUNC_16B 0
#define UART_FUNC_32B 0
#define UART_FUNC_64B 0
#define UART_FUNC_P   0
/***********************************************/

#include <avr/interrupt.h>
#include <inttypes.h>

#define UART_DD_RX (1 << RXEN)
#define UART_DD_TX (1 << TXEN)
#define UART_DD_BOTH (UART_DD_RX | UART_DD_TX)

#if(UART_FRAME_8N1)
	void uart_init(uint32_t baud, uint8_t dataDirection);
#else
	#define UART_PAR_NONE 0
	#define UART_PAR_EVEN (1 << UPM1)
	#define UART_PAR_ODD ((1 << UPM1) | (1 << UPM0))

	#define UART_CS_5B 0
	#define UART_CS_6B 1
	#define UART_CS_7B 2
	#define UART_CS_8B 3
	#define UART_CS_9B 7

	#define UART_STOP_1B 0
	#define UART_STOP_2B 1
	void uart_init(uint32_t baud, uint8_t dataDirection, uint8_t charSize, uint8_t parity, uint8_t stopBits);
#endif

ISR(USART_UDRE_vect);
ISR(USART_RXC_vect);
void uart_transmit(uint8_t data);
uint8_t uart_receive();
void uart_transmitS(char* data);

#if UART_FUNC_16B
	void uart_transmit16(uint16_t data);
	uint16_t uart_receive16();
#endif

#if UART_FUNC_32B
	void uart_transmit32(uint32_t data);
	uint32_t uart_receive32();
#endif

#if UART_FUNC_64B
	void uart_transmit64(uint64_t data);
	uint64_t uart_receive64();
#endif

#if UART_FUNC_P
	void uart_transmitP(uint8_t* data);
	#if UART_FUNC_16B
		void uart_transmit16P(uint16_t* data);
	#endif
	#if UART_FUNC_32B
		void uart_transmit32P(uint32_t* data);
	#endif
	#if UART_FUNC_64B
		void uart_transmit64P(uint64_t* data);
	#endif
#endif

#endif /* UARTLIB_H_ */
